{% extends 'admin/change_list.html' %}
{% load admin_list admin_totals %}

{% block result_list %}
  {% if action_form and actions_on_top and cl.show_admin_actions %}{% admin_actions %}{% endif %}
  {% result_list_totals cl %}
  {% if action_form and actions_on_bottom and cl.show_admin_actions %}{% admin_actions %}{% endif %}
{% endblock %}
